@@ -1,19 +1,18 @@
 #*** UploadMirror.pm ***#
-# Copyright (C) 2006 Torsten Knorr
+# Copyright (C) 2005 - 2008 by Torsten Knorr
 # create-soft@tiscali.de
 # All rights reserved!
 #------------------------------------------------
 package Net::UploadMirror;
 #------------------------------------------------
  use strict;
- use warnings;
  use Net::MirrorDir;
  use Storable;
  use File::Basename;
  use vars '$AUTOLOAD';
 #------------------------------------------------
  @Net::UploadMirror::ISA = qw(Net::MirrorDir);
- $Net::UploadMirror::VERSION = '0.06';
+ $Net::UploadMirror::VERSION = '0.07';
 #-------------------------------------------------
  sub Update
  	{
@@ -218,7 +217,7 @@ Net::UploadMirror - Perl extension for mirroring a local directory via FTP to th
  $um->Update();
  
  or more detailed
- my $um = Net::UploadMirror->new(
+ my $md = Net::MirrorDir->new(
  	ftpserver		=> "my_ftp.hostname.com",
  	usr		=> "my_ftp_usr_name",
  	pass		=> "my_ftp_password",
@@ -228,10 +227,17 @@ Net::UploadMirror - Perl extension for mirroring a local directory via FTP to th
  	timeout		=> 60 # default 30
  	delete		=> "enable" # default "disabled"
  	connection	=> $ftp_object, # default undef
+# "exclusions" default empty arrayreferences [ ]
  	exclusions	=> ["private.txt", "Thumbs.db", ".sys", ".log"],
+# "subset" default empty arrayreferences [ ]
+ 	subset		=> [".txt, ".pl", ".html", "htm", ".gif", ".jpg", ".css", ".js", ".png"]
+# or substrings in pathnames
+#	exclusions	=> ["psw", "forbidden_code"]
+#	subset		=> ["name", "my_files"]
+# or you can use regular expressions
+# 	exclusinos	=> [qr/SYSTEM/i, $regex]
+# 	subset		=> {qr/(?i:HOME)(?i:PAGE)?/, $regex]
  	);
- $um->SetLocalDir("home/nameB/homepageB");
- print("hostname : ", $um->get_ftpserver(), "\n");
  $um->Update();
 
 =head1 DESCRIPTION
@@ -242,95 +248,16 @@ worked on locally. It is not developt for mirroring large archivs.
 But there are not in principle any limits.
 
 =head1 Constructor and Initialization
-
 =item (object) new (options)
-
-=head2 required optines
-
-=item ftpserver
-the hostname of the ftp-server
-
-=item usr	
-the username for authentification
-
-=item pass
-password for authentification
-
-=head2 optional optiones
-
-=item localdir
-local directory to upload or update, default '.'
-
-=item remotedir
-remote location to store the files, default '/' 
-
-=item debug
-set it true for more information about the upload-process, default 1 
-
-=item timeout
-the timeout for the ftp-serverconnection
-
-=item delete
-if you want locally removed files or directories also removed on the remote 
-server set this attribute to "enable", default "disabled"
-
-=item connection
-takes a Net::FTP-object you should not use that,
-it is produced automatically by the UploadMirror-object
-Following functions of the used FTP-object should be identical
-to the Net::FTP-object functions.
- 	cwd(path), 
- 	size(file), 
- 	mdtm(file), 
- 	ls(path),
-
-=item exclusions
-a reference to a list of strings interpreted as regular-expressios ("regex") 
-matching to something in the local pathnames, you do not want to upload, 
-default empty list [ ]
-It is recommended that the local directory no critical files contains!!!
-
-=item (value) get_option (void)
-=item (1)  set_option (value)
-The functions are generated by AUTOLOAD for all options.
-The syntax is not case-sensitive and the character '_' is optional.
+ Net::UploadMirror is a derived class from Net::MirrorDir.
+ For detailed information about constructor or options
+ read the documentation of Net::MirrorDir.
 
 =head2 methods
 
 =item (1) Update (void)
 call this function for mirroring automatically, recommended!!!
 
-=item (ref_hash_local_files, ref_hash_local_dirs) ReadLocalDir (void)
-Returns two hashreferences first  the local-files, second the local-directorys
-found in the directory given by the UploadMirror-object,
-uses the attribute "localdir". 
-The values are in the keys.
-
-=item (ref_hash_remotefiles, ref_hash_remote_dirs) ReadRemoteDir (void)
-Returns two hashreferences first the remote-files, second the remote-directorys
-found in the directory given by the UploadMirror-object,
-uses the attribute "remotedir". 
-The values are in the keys.
-
-=item (1) Connect (void)
-Makes the connection to the ftp-server.
-Uses the attributes "ftpserver", "usr" and "pass" given by the UpoadMirror-object.
-
-=item (1) Quit (void)
-Closes the connection with the ftp-server.
-
-=item (ref_hash_local_paths, ref_hash_remote_paths) LocalNotInRemote (ref_list_new_paths)
-Takes two hashreferences, given by the functions ReadLocalDir(); and ReadRemoteDir();
-to compare with each other. Returns a reference of a list with files or directorys found in 
-the local directory but not in the remote location. Uses the attribute "localdir" and 
-"remotedir" given by the UploadMirror-object.
-
-=item (ref_hash_local_paths, ref_hash_remote_paths) RemoteNotInLocal (ref_list_deleted_paths)
-Takes two hashreferences, given by the functions ReadLocalDir(); and ReadRemoteDir();
-to compare with each other. Returns a reference of a list with files or directorys found in 
-the remote location but not in the local directory. Uses of the attribure "localdir" and 
-"remotedir" given by the UploadMirror-object.
-
 =item (ref_hash_modified_files) CheckIfModified (ref_list_local_files)
 Takes a hashreference of local files to compare the last modification stored in a file
 "lastmodified_local" while uploading. Returns a reference of a list.
@@ -370,11 +297,11 @@ Maybe you'll find some. Let me know.
 
 =head1 AUTHOR
 
-Torsten Knorr, E<lt>torstenknorr@tiscali.deE<gt>
+Torsten Knorr, E<lt>create-soft@tiscali.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Torsten Knorr
+Copyright (C) 2005 - 2008 by Torsten Knorr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.9.2 or,
@@ -384,13 +311,3 @@ at your option, any later version of Perl 5 you may have available.
 =cut
 
 
-
-
-
-
-
-
-
-
-
-
